pub type SignedKeyBundlePublic = (KeyBundlePublic, Signature<JournalistEphemeralKey>);Expand description
The public half of an ephemeral key bundle together with the journalist’s self-signature over it.
pub type SignedKeyBundlePublic = (KeyBundlePublic, Signature<JournalistEphemeralKey>);The public half of an ephemeral key bundle together with the journalist’s self-signature over it.